---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To reproduce**
Steps to reproduce the behavior. [click this, type that, see error]

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**System information**
 - OS or Linux distribution: [Ubuntu, Arch, ...]
 - How did you install Konsave? [from the distro's package manager, using pip, directly from git, ...]
 - What version of Konsave are you using? Did you try updating?

**Additional context**
Add any other context about the problem here.
